@@ -1,5 +1,5 @@
 from .scraper import Scraper, TAG_LINK, HTMLSession
-from .url import URL
+from .url import URL, remove_urls, replace_urls
 from .proxy import ProxyManager, PROXY
 from .logging import LogConfig, LOG_LEVEL
 from .versions import __VERSION__
@@ -9,6 +9,8 @@ __all__ = [
     "TAG_LINK",
     "HTMLSession",
     "URL",
+    "remove_urls",
+    "replace_urls",
     "ProxyManager",
     "PROXY",
     "LogConfig",
